@@ -57,6 +57,8 @@ class Task:
         that are set.
     image: str = 'python:3.7'
         The image to use in the execution of the function.
+    daemon: Optional[bool] = None
+        Wether to run the the task as daemon.
     command: Optional[List[str]] = None
         The command to use in the environment where the function runs in order to run the specific function. Note that
         the specified function is parsed, stored as a string, and ultimately placed in a separate file inside the task
@@ -90,6 +92,7 @@ class Task:
         input_artifacts: Optional[List[InputArtifact]] = None,
         output_artifacts: Optional[List[OutputArtifact]] = None,
         image: str = 'python:3.7',
+        daemon: Optional[bool] = None,
         command: Optional[List[str]] = None,
         env_specs: Optional[List[EnvSpec]] = None,
         resources: Resources = Resources(),
@@ -107,6 +110,7 @@ class Task:
         self.validate()
 
         self.image = image
+        self.daemon = daemon
         self.command = command if command else ['python']
         self.env = self.get_env(env_specs)
         self.resources = resources
@@ -526,6 +530,7 @@ class Task:
         """
         return V1alpha1Template(
             name=self.name,
+            daemon=self.daemon,
             script=self.script_def,
             arguments=self.arguments,
             inputs=self.inputs,
